# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SeeAlsoDocOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'children': 'list[SeeAlsoDocOutputV1]',
        'documentation_href': 'str',
        'short_description': 'str',
        'title': 'str'
    }

    attribute_map = {
        'children': 'children',
        'documentation_href': 'documentationHref',
        'short_description': 'shortDescription',
        'title': 'title'
    }

    def __init__(self, children=None, documentation_href=None, short_description=None, title=None):
        """
        SeeAlsoDocOutputV1 - a model defined in Swagger
        """

        self._children = None
        self._documentation_href = None
        self._short_description = None
        self._title = None

        if children is not None:
          self.children = children
        if documentation_href is not None:
          self.documentation_href = documentation_href
        if short_description is not None:
          self.short_description = short_description
        if title is not None:
          self.title = title

    @property
    def children(self):
        """
        Gets the children of this SeeAlsoDocOutputV1.
        Children links of this document

        :return: The children of this SeeAlsoDocOutputV1.
        :rtype: list[SeeAlsoDocOutputV1]
        """
        return self._children

    @children.setter
    def children(self, children):
        """
        Sets the children of this SeeAlsoDocOutputV1.
        Children links of this document

        :param children: The children of this SeeAlsoDocOutputV1.
        :type: list[SeeAlsoDocOutputV1]
        """

        self._children = children

    @property
    def documentation_href(self):
        """
        Gets the documentation_href of this SeeAlsoDocOutputV1.
        The href of the link

        :return: The documentation_href of this SeeAlsoDocOutputV1.
        :rtype: str
        """
        return self._documentation_href

    @documentation_href.setter
    def documentation_href(self, documentation_href):
        """
        Sets the documentation_href of this SeeAlsoDocOutputV1.
        The href of the link

        :param documentation_href: The documentation_href of this SeeAlsoDocOutputV1.
        :type: str
        """

        self._documentation_href = documentation_href

    @property
    def short_description(self):
        """
        Gets the short_description of this SeeAlsoDocOutputV1.
        A short description of the linked content

        :return: The short_description of this SeeAlsoDocOutputV1.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this SeeAlsoDocOutputV1.
        A short description of the linked content

        :param short_description: The short_description of this SeeAlsoDocOutputV1.
        :type: str
        """

        self._short_description = short_description

    @property
    def title(self):
        """
        Gets the title of this SeeAlsoDocOutputV1.
        The title of the link

        :return: The title of this SeeAlsoDocOutputV1.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this SeeAlsoDocOutputV1.
        The title of the link

        :param title: The title of this SeeAlsoDocOutputV1.
        :type: str
        """

        self._title = title

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SeeAlsoDocOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ValidateCronOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error': 'str',
        'next_run_time': 'str',
        'quartz_cron_expression': 'str',
        'quartz_cron_expression_summary': 'str',
        'valid': 'bool'
    }

    attribute_map = {
        'error': 'error',
        'next_run_time': 'nextRunTime',
        'quartz_cron_expression': 'quartzCronExpression',
        'quartz_cron_expression_summary': 'quartzCronExpressionSummary',
        'valid': 'valid'
    }

    def __init__(self, error=None, next_run_time=None, quartz_cron_expression=None, quartz_cron_expression_summary=None, valid=False):
        """
        ValidateCronOutputV1 - a model defined in Swagger
        """

        self._error = None
        self._next_run_time = None
        self._quartz_cron_expression = None
        self._quartz_cron_expression_summary = None
        self._valid = None

        if error is not None:
          self.error = error
        if next_run_time is not None:
          self.next_run_time = next_run_time
        if quartz_cron_expression is not None:
          self.quartz_cron_expression = quartz_cron_expression
        if quartz_cron_expression_summary is not None:
          self.quartz_cron_expression_summary = quartz_cron_expression_summary
        if valid is not None:
          self.valid = valid

    @property
    def error(self):
        """
        Gets the error of this ValidateCronOutputV1.
        The error message if the Quartz cron expression is not valid

        :return: The error of this ValidateCronOutputV1.
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """
        Sets the error of this ValidateCronOutputV1.
        The error message if the Quartz cron expression is not valid

        :param error: The error of this ValidateCronOutputV1.
        :type: str
        """

        self._error = error

    @property
    def next_run_time(self):
        """
        Gets the next_run_time of this ValidateCronOutputV1.
        The next time after the input nextValidTimeAfter in which the schedule will trigger

        :return: The next_run_time of this ValidateCronOutputV1.
        :rtype: str
        """
        return self._next_run_time

    @next_run_time.setter
    def next_run_time(self, next_run_time):
        """
        Sets the next_run_time of this ValidateCronOutputV1.
        The next time after the input nextValidTimeAfter in which the schedule will trigger

        :param next_run_time: The next_run_time of this ValidateCronOutputV1.
        :type: str
        """

        self._next_run_time = next_run_time

    @property
    def quartz_cron_expression(self):
        """
        Gets the quartz_cron_expression of this ValidateCronOutputV1.
        The input Quartz cron expression

        :return: The quartz_cron_expression of this ValidateCronOutputV1.
        :rtype: str
        """
        return self._quartz_cron_expression

    @quartz_cron_expression.setter
    def quartz_cron_expression(self, quartz_cron_expression):
        """
        Sets the quartz_cron_expression of this ValidateCronOutputV1.
        The input Quartz cron expression

        :param quartz_cron_expression: The quartz_cron_expression of this ValidateCronOutputV1.
        :type: str
        """

        self._quartz_cron_expression = quartz_cron_expression

    @property
    def quartz_cron_expression_summary(self):
        """
        Gets the quartz_cron_expression_summary of this ValidateCronOutputV1.
        The full summary of the cron expression

        :return: The quartz_cron_expression_summary of this ValidateCronOutputV1.
        :rtype: str
        """
        return self._quartz_cron_expression_summary

    @quartz_cron_expression_summary.setter
    def quartz_cron_expression_summary(self, quartz_cron_expression_summary):
        """
        Sets the quartz_cron_expression_summary of this ValidateCronOutputV1.
        The full summary of the cron expression

        :param quartz_cron_expression_summary: The quartz_cron_expression_summary of this ValidateCronOutputV1.
        :type: str
        """

        self._quartz_cron_expression_summary = quartz_cron_expression_summary

    @property
    def valid(self):
        """
        Gets the valid of this ValidateCronOutputV1.
        True if the Quartz cron expression was parsed and there's a valid nextRunTime

        :return: The valid of this ValidateCronOutputV1.
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """
        Sets the valid of this ValidateCronOutputV1.
        True if the Quartz cron expression was parsed and there's a valid nextRunTime

        :param valid: The valid of this ValidateCronOutputV1.
        :type: bool
        """

        self._valid = valid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ValidateCronOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RequestOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'activities': 'list[ActivityOutputV1]',
        'activity_graph': 'ActivityGraphOutputV1',
        'detailed_meters': 'list[DetailedMeterOutputV1]',
        'detailed_timers': 'list[DetailedTimerOutputV1]',
        'flame_graph': 'FoldedStackNodeV1',
        'href': 'str',
        'parallelization_count': 'int',
        'parameters': 'dict(str, list[str])',
        'progress': 'ProgressInformationOutputV1',
        'request_method': 'str',
        'request_path': 'str',
        'run_duration': 'int',
        'user_email': 'str',
        'username': 'str'
    }

    attribute_map = {
        'activities': 'activities',
        'activity_graph': 'activityGraph',
        'detailed_meters': 'detailedMeters',
        'detailed_timers': 'detailedTimers',
        'flame_graph': 'flameGraph',
        'href': 'href',
        'parallelization_count': 'parallelizationCount',
        'parameters': 'parameters',
        'progress': 'progress',
        'request_method': 'requestMethod',
        'request_path': 'requestPath',
        'run_duration': 'runDuration',
        'user_email': 'userEmail',
        'username': 'username'
    }

    def __init__(self, activities=None, activity_graph=None, detailed_meters=None, detailed_timers=None, flame_graph=None, href=None, parallelization_count=None, parameters=None, progress=None, request_method=None, request_path=None, run_duration=None, user_email=None, username=None):
        """
        RequestOutputV1 - a model defined in Swagger
        """

        self._activities = None
        self._activity_graph = None
        self._detailed_meters = None
        self._detailed_timers = None
        self._flame_graph = None
        self._href = None
        self._parallelization_count = None
        self._parameters = None
        self._progress = None
        self._request_method = None
        self._request_path = None
        self._run_duration = None
        self._user_email = None
        self._username = None

        if activities is not None:
          self.activities = activities
        if activity_graph is not None:
          self.activity_graph = activity_graph
        if detailed_meters is not None:
          self.detailed_meters = detailed_meters
        if detailed_timers is not None:
          self.detailed_timers = detailed_timers
        if flame_graph is not None:
          self.flame_graph = flame_graph
        if href is not None:
          self.href = href
        if parallelization_count is not None:
          self.parallelization_count = parallelization_count
        if parameters is not None:
          self.parameters = parameters
        if progress is not None:
          self.progress = progress
        if request_method is not None:
          self.request_method = request_method
        if request_path is not None:
          self.request_path = request_path
        if run_duration is not None:
          self.run_duration = run_duration
        if user_email is not None:
          self.user_email = user_email
        if username is not None:
          self.username = username

    @property
    def activities(self):
        """
        Gets the activities of this RequestOutputV1.
        The current chain of activities for the request. The last activity in the list represents the current operation being performed.

        :return: The activities of this RequestOutputV1.
        :rtype: list[ActivityOutputV1]
        """
        return self._activities

    @activities.setter
    def activities(self, activities):
        """
        Sets the activities of this RequestOutputV1.
        The current chain of activities for the request. The last activity in the list represents the current operation being performed.

        :param activities: The activities of this RequestOutputV1.
        :type: list[ActivityOutputV1]
        """

        self._activities = activities

    @property
    def activity_graph(self):
        """
        Gets the activity_graph of this RequestOutputV1.

        :return: The activity_graph of this RequestOutputV1.
        :rtype: ActivityGraphOutputV1
        """
        return self._activity_graph

    @activity_graph.setter
    def activity_graph(self, activity_graph):
        """
        Sets the activity_graph of this RequestOutputV1.

        :param activity_graph: The activity_graph of this RequestOutputV1.
        :type: ActivityGraphOutputV1
        """

        self._activity_graph = activity_graph

    @property
    def detailed_meters(self):
        """
        Gets the detailed_meters of this RequestOutputV1.
        All metered items that are attributable to the processing of the request.

        :return: The detailed_meters of this RequestOutputV1.
        :rtype: list[DetailedMeterOutputV1]
        """
        return self._detailed_meters

    @detailed_meters.setter
    def detailed_meters(self, detailed_meters):
        """
        Sets the detailed_meters of this RequestOutputV1.
        All metered items that are attributable to the processing of the request.

        :param detailed_meters: The detailed_meters of this RequestOutputV1.
        :type: list[DetailedMeterOutputV1]
        """

        self._detailed_meters = detailed_meters

    @property
    def detailed_timers(self):
        """
        Gets the detailed_timers of this RequestOutputV1.
        All timed events that are attributable to the processing of the request.

        :return: The detailed_timers of this RequestOutputV1.
        :rtype: list[DetailedTimerOutputV1]
        """
        return self._detailed_timers

    @detailed_timers.setter
    def detailed_timers(self, detailed_timers):
        """
        Sets the detailed_timers of this RequestOutputV1.
        All timed events that are attributable to the processing of the request.

        :param detailed_timers: The detailed_timers of this RequestOutputV1.
        :type: list[DetailedTimerOutputV1]
        """

        self._detailed_timers = detailed_timers

    @property
    def flame_graph(self):
        """
        Gets the flame_graph of this RequestOutputV1.

        :return: The flame_graph of this RequestOutputV1.
        :rtype: FoldedStackNodeV1
        """
        return self._flame_graph

    @flame_graph.setter
    def flame_graph(self, flame_graph):
        """
        Sets the flame_graph of this RequestOutputV1.

        :param flame_graph: The flame_graph of this RequestOutputV1.
        :type: FoldedStackNodeV1
        """

        self._flame_graph = flame_graph

    @property
    def href(self):
        """
        Gets the href of this RequestOutputV1.
        The href that can be used to interact with the request

        :return: The href of this RequestOutputV1.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this RequestOutputV1.
        The href that can be used to interact with the request

        :param href: The href of this RequestOutputV1.
        :type: str
        """
        if href is None:
            raise ValueError("Invalid value for `href`, must not be `None`")

        self._href = href

    @property
    def parallelization_count(self):
        """
        Gets the parallelization_count of this RequestOutputV1.
        The number of threads working on this request

        :return: The parallelization_count of this RequestOutputV1.
        :rtype: int
        """
        return self._parallelization_count

    @parallelization_count.setter
    def parallelization_count(self, parallelization_count):
        """
        Sets the parallelization_count of this RequestOutputV1.
        The number of threads working on this request

        :param parallelization_count: The parallelization_count of this RequestOutputV1.
        :type: int
        """
        if parallelization_count is None:
            raise ValueError("Invalid value for `parallelization_count`, must not be `None`")

        self._parallelization_count = parallelization_count

    @property
    def parameters(self):
        """
        Gets the parameters of this RequestOutputV1.
        The list of HTTP parameters

        :return: The parameters of this RequestOutputV1.
        :rtype: dict(str, list[str])
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this RequestOutputV1.
        The list of HTTP parameters

        :param parameters: The parameters of this RequestOutputV1.
        :type: dict(str, list[str])
        """

        self._parameters = parameters

    @property
    def progress(self):
        """
        Gets the progress of this RequestOutputV1.

        :return: The progress of this RequestOutputV1.
        :rtype: ProgressInformationOutputV1
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """
        Sets the progress of this RequestOutputV1.

        :param progress: The progress of this RequestOutputV1.
        :type: ProgressInformationOutputV1
        """

        self._progress = progress

    @property
    def request_method(self):
        """
        Gets the request_method of this RequestOutputV1.
        The request method that this request was created for (GET, POST, DELETE)

        :return: The request_method of this RequestOutputV1.
        :rtype: str
        """
        return self._request_method

    @request_method.setter
    def request_method(self, request_method):
        """
        Sets the request_method of this RequestOutputV1.
        The request method that this request was created for (GET, POST, DELETE)

        :param request_method: The request_method of this RequestOutputV1.
        :type: str
        """
        if request_method is None:
            raise ValueError("Invalid value for `request_method`, must not be `None`")

        self._request_method = request_method

    @property
    def request_path(self):
        """
        Gets the request_path of this RequestOutputV1.
        The URI path that this request was created for

        :return: The request_path of this RequestOutputV1.
        :rtype: str
        """
        return self._request_path

    @request_path.setter
    def request_path(self, request_path):
        """
        Sets the request_path of this RequestOutputV1.
        The URI path that this request was created for

        :param request_path: The request_path of this RequestOutputV1.
        :type: str
        """
        if request_path is None:
            raise ValueError("Invalid value for `request_path`, must not be `None`")

        self._request_path = request_path

    @property
    def run_duration(self):
        """
        Gets the run_duration of this RequestOutputV1.
        The time (in nanoseconds) that this request has been running for

        :return: The run_duration of this RequestOutputV1.
        :rtype: int
        """
        return self._run_duration

    @run_duration.setter
    def run_duration(self, run_duration):
        """
        Sets the run_duration of this RequestOutputV1.
        The time (in nanoseconds) that this request has been running for

        :param run_duration: The run_duration of this RequestOutputV1.
        :type: int
        """
        if run_duration is None:
            raise ValueError("Invalid value for `run_duration`, must not be `None`")

        self._run_duration = run_duration

    @property
    def user_email(self):
        """
        Gets the user_email of this RequestOutputV1.
        The email of the user that created this request

        :return: The user_email of this RequestOutputV1.
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email):
        """
        Sets the user_email of this RequestOutputV1.
        The email of the user that created this request

        :param user_email: The user_email of this RequestOutputV1.
        :type: str
        """
        if user_email is None:
            raise ValueError("Invalid value for `user_email`, must not be `None`")

        self._user_email = user_email

    @property
    def username(self):
        """
        Gets the username of this RequestOutputV1.
        The username of the user that created this request

        :return: The username of this RequestOutputV1.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this RequestOutputV1.
        The username of the user that created this request

        :param username: The username of this RequestOutputV1.
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")

        self._username = username

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RequestOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class EmailerConfigurationOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max_number_of_attachments': 'int',
        'max_attachments_size_in_mb': 'float',
        'allowed_attachment_types': 'list[str]'
    }

    attribute_map = {
        'max_number_of_attachments': 'maxNumberOfAttachments',
        'max_attachments_size_in_mb': 'maxAttachmentsSizeInMB',
        'allowed_attachment_types': 'allowedAttachmentTypes'
    }

    def __init__(self, max_number_of_attachments=None, max_attachments_size_in_mb=None, allowed_attachment_types=None):
        """
        EmailerConfigurationOutputV1 - a model defined in Swagger
        """

        self._max_number_of_attachments = None
        self._max_attachments_size_in_mb = None
        self._allowed_attachment_types = None

        if max_number_of_attachments is not None:
          self.max_number_of_attachments = max_number_of_attachments
        if max_attachments_size_in_mb is not None:
          self.max_attachments_size_in_mb = max_attachments_size_in_mb
        if allowed_attachment_types is not None:
          self.allowed_attachment_types = allowed_attachment_types

    @property
    def max_number_of_attachments(self):
        """
        Gets the max_number_of_attachments of this EmailerConfigurationOutputV1.
        The maximum number of attachments allowed in an email.

        :return: The max_number_of_attachments of this EmailerConfigurationOutputV1.
        :rtype: int
        """
        return self._max_number_of_attachments

    @max_number_of_attachments.setter
    def max_number_of_attachments(self, max_number_of_attachments):
        """
        Sets the max_number_of_attachments of this EmailerConfigurationOutputV1.
        The maximum number of attachments allowed in an email.

        :param max_number_of_attachments: The max_number_of_attachments of this EmailerConfigurationOutputV1.
        :type: int
        """
        if max_number_of_attachments is None:
            raise ValueError("Invalid value for `max_number_of_attachments`, must not be `None`")

        self._max_number_of_attachments = max_number_of_attachments

    @property
    def max_attachments_size_in_mb(self):
        """
        Gets the max_attachments_size_in_mb of this EmailerConfigurationOutputV1.
        The maximum size, in megabytes, for all attachments in an email.

        :return: The max_attachments_size_in_mb of this EmailerConfigurationOutputV1.
        :rtype: float
        """
        return self._max_attachments_size_in_mb

    @max_attachments_size_in_mb.setter
    def max_attachments_size_in_mb(self, max_attachments_size_in_mb):
        """
        Sets the max_attachments_size_in_mb of this EmailerConfigurationOutputV1.
        The maximum size, in megabytes, for all attachments in an email.

        :param max_attachments_size_in_mb: The max_attachments_size_in_mb of this EmailerConfigurationOutputV1.
        :type: float
        """
        if max_attachments_size_in_mb is None:
            raise ValueError("Invalid value for `max_attachments_size_in_mb`, must not be `None`")

        self._max_attachments_size_in_mb = max_attachments_size_in_mb

    @property
    def allowed_attachment_types(self):
        """
        Gets the allowed_attachment_types of this EmailerConfigurationOutputV1.
        The list of allowed MIME types for attachments

        :return: The allowed_attachment_types of this EmailerConfigurationOutputV1.
        :rtype: list[str]
        """
        return self._allowed_attachment_types

    @allowed_attachment_types.setter
    def allowed_attachment_types(self, allowed_attachment_types):
        """
        Sets the allowed_attachment_types of this EmailerConfigurationOutputV1.
        The list of allowed MIME types for attachments

        :param allowed_attachment_types: The allowed_attachment_types of this EmailerConfigurationOutputV1.
        :type: list[str]
        """
        if allowed_attachment_types is None:
            raise ValueError("Invalid value for `allowed_attachment_types`, must not be `None`")

        self._allowed_attachment_types = allowed_attachment_types

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, EmailerConfigurationOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class NotifiableReportOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contextual_text': 'str',
        'created_at': 'str',
        'enabled': 'bool',
        'id': 'str',
        'name': 'str',
        'owner': 'IdentityPreviewV1',
        'owner_id': 'str'
    }

    attribute_map = {
        'contextual_text': 'contextualText',
        'created_at': 'createdAt',
        'enabled': 'enabled',
        'id': 'id',
        'name': 'name',
        'owner': 'owner',
        'owner_id': 'ownerId'
    }

    def __init__(self, contextual_text=None, created_at=None, enabled=None, id=None, name=None, owner=None, owner_id=None):
        """
        NotifiableReportOutputV1 - a model defined in Swagger
        """

        self._contextual_text = None
        self._created_at = None
        self._enabled = None
        self._id = None
        self._name = None
        self._owner = None
        self._owner_id = None

        if contextual_text is not None:
          self.contextual_text = contextual_text
        if created_at is not None:
          self.created_at = created_at
        if enabled is not None:
          self.enabled = enabled
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if owner is not None:
          self.owner = owner
        if owner_id is not None:
          self.owner_id = owner_id

    @property
    def contextual_text(self):
        """
        Gets the contextual_text of this NotifiableReportOutputV1.
        Additional context about the notifications

        :return: The contextual_text of this NotifiableReportOutputV1.
        :rtype: str
        """
        return self._contextual_text

    @contextual_text.setter
    def contextual_text(self, contextual_text):
        """
        Sets the contextual_text of this NotifiableReportOutputV1.
        Additional context about the notifications

        :param contextual_text: The contextual_text of this NotifiableReportOutputV1.
        :type: str
        """

        self._contextual_text = contextual_text

    @property
    def created_at(self):
        """
        Gets the created_at of this NotifiableReportOutputV1.
        The time the report was created

        :return: The created_at of this NotifiableReportOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this NotifiableReportOutputV1.
        The time the report was created

        :param created_at: The created_at of this NotifiableReportOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def enabled(self):
        """
        Gets the enabled of this NotifiableReportOutputV1.
        Whether this report is enabled or not

        :return: The enabled of this NotifiableReportOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this NotifiableReportOutputV1.
        Whether this report is enabled or not

        :param enabled: The enabled of this NotifiableReportOutputV1.
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")

        self._enabled = enabled

    @property
    def id(self):
        """
        Gets the id of this NotifiableReportOutputV1.
        ID of the report

        :return: The id of this NotifiableReportOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NotifiableReportOutputV1.
        ID of the report

        :param id: The id of this NotifiableReportOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this NotifiableReportOutputV1.
        Name of the Organizer topic and document name associated with the report

        :return: The name of this NotifiableReportOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NotifiableReportOutputV1.
        Name of the Organizer topic and document name associated with the report

        :param name: The name of this NotifiableReportOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def owner(self):
        """
        Gets the owner of this NotifiableReportOutputV1.

        :return: The owner of this NotifiableReportOutputV1.
        :rtype: IdentityPreviewV1
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this NotifiableReportOutputV1.

        :param owner: The owner of this NotifiableReportOutputV1.
        :type: IdentityPreviewV1
        """

        self._owner = owner

    @property
    def owner_id(self):
        """
        Gets the owner_id of this NotifiableReportOutputV1.
        ID of the report's owner

        :return: The owner_id of this NotifiableReportOutputV1.
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """
        Sets the owner_id of this NotifiableReportOutputV1.
        ID of the report's owner

        :param owner_id: The owner_id of this NotifiableReportOutputV1.
        :type: str
        """
        if owner_id is None:
            raise ValueError("Invalid value for `owner_id`, must not be `None`")

        self._owner_id = owner_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, NotifiableReportOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

__version__ = "64.1.2"

# import apis into sdk package
from .api.access_keys_api import AccessKeysApi
from .api.add_ons_api import AddOnsApi
from .api.agents_api import AgentsApi
from .api.annotations_api import AnnotationsApi
from .api.assets_api import AssetsApi
from .api.assistants_api import AssistantsApi
from .api.audit_api import AuditApi
from .api.auth_api import AuthApi
from .api.condition_monitors_api import ConditionMonitorsApi
from .api.conditions_api import ConditionsApi
from .api.content_api import ContentApi
from .api.context_api import ContextApi
from .api.datafiles_api import DatafilesApi
from .api.datasources_api import DatasourcesApi
from .api.display_templates_api import DisplayTemplatesApi
from .api.displays_api import DisplaysApi
from .api.export_api import ExportApi
from .api.folders_api import FoldersApi
from .api.formulas_api import FormulasApi
from .api.graph_ql_api import GraphQLApi
from .api.items_api import ItemsApi
from .api.jobs_api import JobsApi
from .api.logs_api import LogsApi
from .api.metrics_api import MetricsApi
from .api.monitors_api import MonitorsApi
from .api.networks_api import NetworksApi
from .api.notification_configurations_api import NotificationConfigurationsApi
from .api.notifier_api import NotifierApi
from .api.plugins_api import PluginsApi
from .api.projects_api import ProjectsApi
from .api.report_templates_api import ReportTemplatesApi
from .api.reports_api import ReportsApi
from .api.requests_api import RequestsApi
from .api.scim_api import SCIMApi
from .api.scalars_api import ScalarsApi
from .api.signals_api import SignalsApi
from .api.subscriptions_api import SubscriptionsApi
from .api.system_api import SystemApi
from .api.table_definitions_api import TableDefinitionsApi
from .api.trees_api import TreesApi
from .api.unstable_api import UnstableApi
from .api.usage_api import UsageApi
from .api.user_groups_api import UserGroupsApi
from .api.users_api import UsersApi
from .api.workbooks_api import WorkbooksApi

# import models into sdk package
from .models.access_key_input_v1 import AccessKeyInputV1
from .models.access_key_output_list_v1 import AccessKeyOutputListV1
from .models.access_key_output_v1 import AccessKeyOutputV1
from .models.ace_input_v1 import AceInputV1
from .models.ace_output_v1 import AceOutputV1
from .models.acl_input_v1 import AclInputV1
from .models.acl_output_v1 import AclOutputV1
from .models.activity_graph_output_v1 import ActivityGraphOutputV1
from .models.activity_output_v1 import ActivityOutputV1
from .models.add_on_input_v1 import AddOnInputV1
from .models.add_on_output_list_v1 import AddOnOutputListV1
from .models.add_on_output_v1 import AddOnOutputV1
from .models.add_on_preview_output_list_v1 import AddOnPreviewOutputListV1
from .models.add_on_preview_v1 import AddOnPreviewV1
from .models.add_on_tool_input_v1 import AddOnToolInputV1
from .models.add_on_tool_output_v1 import AddOnToolOutputV1
from .models.administrator_contact_information_v1 import AdministratorContactInformationV1
from .models.agent_input_v1 import AgentInputV1
from .models.agent_key_output_v1 import AgentKeyOutputV1
from .models.agent_orchestrator_output_v1 import AgentOrchestratorOutputV1
from .models.agent_output_v1 import AgentOutputV1
from .models.agent_status_output_v1 import AgentStatusOutputV1
from .models.agent_status_v1 import AgentStatusV1
from .models.annotation_image_link_output_v1 import AnnotationImageLinkOutputV1
from .models.annotation_input_v1 import AnnotationInputV1
from .models.annotation_interest_input_v1 import AnnotationInterestInputV1
from .models.annotation_interest_output_v1 import AnnotationInterestOutputV1
from .models.annotation_list_output_v1 import AnnotationListOutputV1
from .models.annotation_output_v1 import AnnotationOutputV1
from .models.archive_output_v1 import ArchiveOutputV1
from .models.asset_batch_input_v1 import AssetBatchInputV1
from .models.asset_error import AssetError
from .models.asset_group_asset_input_v1 import AssetGroupAssetInputV1
from .models.asset_group_input_v1 import AssetGroupInputV1
from .models.asset_group_output_v1 import AssetGroupOutputV1
from .models.asset_group_root_input_v1 import AssetGroupRootInputV1
from .models.asset_group_tree_output_v1 import AssetGroupTreeOutputV1
from .models.asset_input_v1 import AssetInputV1
from .models.asset_output_v1 import AssetOutputV1
from .models.asset_selection_input_v1 import AssetSelectionInputV1
from .models.asset_selection_output_v1 import AssetSelectionOutputV1
from .models.asset_tree_batch_input_v1 import AssetTreeBatchInputV1
from .models.asset_tree_output_v1 import AssetTreeOutputV1
from .models.asset_tree_single_input_v1 import AssetTreeSingleInputV1
from .models.assistant_status_v1 import AssistantStatusV1
from .models.attachment_input_v1 import AttachmentInputV1
from .models.audit_output_list_v1 import AuditOutputListV1
from .models.audit_output_v1 import AuditOutputV1
from .models.auth_input_v1 import AuthInputV1
from .models.auth_providers_output_v1 import AuthProvidersOutputV1
from .models.authoritative_region_output_v1 import AuthoritativeRegionOutputV1
from .models.boolean_configuration_field_output_v1 import BooleanConfigurationFieldOutputV1
from .models.cache_block import CacheBlock
from .models.cache_info_v1 import CacheInfoV1
from .models.calculated_item_output_v1 import CalculatedItemOutputV1
from .models.capsule_input_v1 import CapsuleInputV1
from .models.capsule_property_input_v1 import CapsulePropertyInputV1
from .models.capsule_property_output_v1 import CapsulePropertyOutputV1
from .models.capsule_v1 import CapsuleV1
from .models.capsules_input_v1 import CapsulesInputV1
from .models.capsules_output_v1 import CapsulesOutputV1
from .models.capsules_overwrite_input_v1 import CapsulesOverwriteInputV1
from .models.channel_output_v1 import ChannelOutputV1
from .models.column_definition_input_list_v1 import ColumnDefinitionInputListV1
from .models.column_definition_input_v1 import ColumnDefinitionInputV1
from .models.column_definition_output_v1 import ColumnDefinitionOutputV1
from .models.column_rule_ancestor_input_v1 import ColumnRuleAncestorInputV1
from .models.column_rule_concat_input_v1 import ColumnRuleConcatInputV1
from .models.column_rule_event_property_input_v1 import ColumnRuleEventPropertyInputV1
from .models.column_rule_input_v1 import ColumnRuleInputV1
from .models.column_rule_item_property_input_v1 import ColumnRuleItemPropertyInputV1
from .models.column_rule_output_v1 import ColumnRuleOutputV1
from .models.column_rule_path_input_v1 import ColumnRulePathInputV1
from .models.condition_batch_input_v1 import ConditionBatchInputV1
from .models.condition_input_v1 import ConditionInputV1
from .models.condition_monitor_input_v1 import ConditionMonitorInputV1
from .models.condition_monitor_notification_configuration_input_v1 import ConditionMonitorNotificationConfigurationInputV1
from .models.condition_monitor_output_v1 import ConditionMonitorOutputV1
from .models.condition_notification_output_list_v1 import ConditionNotificationOutputListV1
from .models.condition_notification_output_v1 import ConditionNotificationOutputV1
from .models.condition_output_v1 import ConditionOutputV1
from .models.condition_update_input_v1 import ConditionUpdateInputV1
from .models.configuration_field_output_v1 import ConfigurationFieldOutputV1
from .models.configuration_input_v1 import ConfigurationInputV1
from .models.configuration_option_input_v1 import ConfigurationOptionInputV1
from .models.configuration_option_output_simple_v1 import ConfigurationOptionOutputSimpleV1
from .models.configuration_option_output_v1 import ConfigurationOptionOutputV1
from .models.configuration_output_v1 import ConfigurationOutputV1
from .models.configured_directives_output_v1 import ConfiguredDirectivesOutputV1
from .models.connection_input_v1 import ConnectionInputV1
from .models.connection_output_v1 import ConnectionOutputV1
from .models.connection_status_output_v1 import ConnectionStatusOutputV1
from .models.connection_status_v1 import ConnectionStatusV1
from .models.connections_output_v1 import ConnectionsOutputV1
from .models.connector_input_v1 import ConnectorInputV1
from .models.connector_output_v1 import ConnectorOutputV1
from .models.connectors_output_v1 import ConnectorsOutputV1
from .models.content_input_v1 import ContentInputV1
from .models.content_output_v1 import ContentOutputV1
from .models.content_with_metadata_list_output_v1 import ContentWithMetadataListOutputV1
from .models.content_with_metadata_output_v1 import ContentWithMetadataOutputV1
from .models.context_comment_input_v1 import ContextCommentInputV1
from .models.context_comment_output_v1 import ContextCommentOutputV1
from .models.context_label_input_v1 import ContextLabelInputV1
from .models.context_label_output_v1 import ContextLabelOutputV1
from .models.context_opaque_input_v1 import ContextOpaqueInputV1
from .models.context_opaque_output_v1 import ContextOpaqueOutputV1
from .models.csv_datafile_output_v1 import CsvDatafileOutputV1
from .models.datafile_input_v1 import DatafileInputV1
from .models.datafile_output_v1 import DatafileOutputV1
from .models.datafiles_csv_body import DatafilesCsvBody
from .models.datasource_clean_up_input_v1 import DatasourceCleanUpInputV1
from .models.datasource_clean_up_output_v1 import DatasourceCleanUpOutputV1
from .models.datasource_input_v1 import DatasourceInputV1
from .models.datasource_output_list_v1 import DatasourceOutputListV1
from .models.datasource_output_v1 import DatasourceOutputV1
from .models.datasource_preview_v1 import DatasourcePreviewV1
from .models.datasource_statistics_v1 import DatasourceStatisticsV1
from .models.datasource_status_output_v1 import DatasourceStatusOutputV1
from .models.datasource_status_v1 import DatasourceStatusV1
from .models.datasource_summary_status_output_v1 import DatasourceSummaryStatusOutputV1
from .models.datasources_status_output_v1 import DatasourcesStatusOutputV1
from .models.date_range_input_v1 import DateRangeInputV1
from .models.date_range_output_v1 import DateRangeOutputV1
from .models.debug_cache_block_output_v1 import DebugCacheBlockOutputV1
from .models.detailed_meter_output_v1 import DetailedMeterOutputV1
from .models.detailed_timer_output_v1 import DetailedTimerOutputV1
from .models.directive_input_v1 import DirectiveInputV1
from .models.display_input_v1 import DisplayInputV1
from .models.display_output_list_v1 import DisplayOutputListV1
from .models.display_output_v1 import DisplayOutputV1
from .models.display_template_input_v1 import DisplayTemplateInputV1
from .models.display_template_output_list_v1 import DisplayTemplateOutputListV1
from .models.display_template_output_v1 import DisplayTemplateOutputV1
from .models.document_backup_output_v1 import DocumentBackupOutputV1
from .models.double_configuration_field_output_v1 import DoubleConfigurationFieldOutputV1
from .models.email_notification_recipient_output_v1 import EmailNotificationRecipientOutputV1
from .models.emailer_configuration_output_v1 import EmailerConfigurationOutputV1
from .models.export_item_v1 import ExportItemV1
from .models.export_items_output_v1 import ExportItemsOutputV1
from .models.export_items_v1 import ExportItemsV1
from .models.export_preview_list_v1 import ExportPreviewListV1
from .models.export_preview_v1 import ExportPreviewV1
from .models.folded_stack_node_v1 import FoldedStackNodeV1
from .models.folder_input_v1 import FolderInputV1
from .models.folder_navigation_output_v1 import FolderNavigationOutputV1
from .models.folder_output_v1 import FolderOutputV1
from .models.formula_compile_input_v1 import FormulaCompileInputV1
from .models.formula_compile_output_v1 import FormulaCompileOutputV1
from .models.formula_compiler_error_output_v1 import FormulaCompilerErrorOutputV1
from .models.formula_dependency_input_v1 import FormulaDependencyInputV1
from .models.formula_doc_example_input_v1 import FormulaDocExampleInputV1
from .models.formula_doc_example_list_input_v1 import FormulaDocExampleListInputV1
from .models.formula_doc_input_v1 import FormulaDocInputV1
from .models.formula_doc_keyword_list_input_v1 import FormulaDocKeywordListInputV1
from .models.formula_doc_output_v1 import FormulaDocOutputV1
from .models.formula_doc_summaries_output_v1 import FormulaDocSummariesOutputV1
from .models.formula_doc_summary_output_v1 import FormulaDocSummaryOutputV1
from .models.formula_error_output_v1 import FormulaErrorOutputV1
from .models.formula_example_output_v1 import FormulaExampleOutputV1
from .models.formula_item_input_v1 import FormulaItemInputV1
from .models.formula_item_output_v1 import FormulaItemOutputV1
from .models.formula_log_entry import FormulaLogEntry
from .models.formula_log_entry_details import FormulaLogEntryDetails
from .models.formula_log_v1 import FormulaLogV1
from .models.formula_package_import_input_v1 import FormulaPackageImportInputV1
from .models.formula_package_import_output_v1 import FormulaPackageImportOutputV1
from .models.formula_package_input_v1 import FormulaPackageInputV1
from .models.formula_package_output_v1 import FormulaPackageOutputV1
from .models.formula_parameter_input_v1 import FormulaParameterInputV1
from .models.formula_parameter_output_v1 import FormulaParameterOutputV1
from .models.formula_run_input_v1 import FormulaRunInputV1
from .models.formula_run_output_v1 import FormulaRunOutputV1
from .models.formula_token import FormulaToken
from .models.formula_update_input_v1 import FormulaUpdateInputV1
from .models.formula_upgrade_change_v1 import FormulaUpgradeChangeV1
from .models.formula_upgrade_output_v1 import FormulaUpgradeOutputV1
from .models.function_input_v1 import FunctionInputV1
from .models.function_parameter_output_v1 import FunctionParameterOutputV1
from .models.function_variant_output_v1 import FunctionVariantOutputV1
from .models.gauge_datum_v1 import GaugeDatumV1
from .models.generic_table_output_v1 import GenericTableOutputV1
from .models.get_add_on_tools_output_v1 import GetAddOnToolsOutputV1
from .models.get_channels_output_v1 import GetChannelsOutputV1
from .models.get_condition_monitor_items_output_v1 import GetConditionMonitorItemsOutputV1
from .models.get_content_items_output_v1 import GetContentItemsOutputV1
from .models.get_date_ranges_output_v1 import GetDateRangesOutputV1
from .models.get_jobs_output_v1 import GetJobsOutputV1
from .models.get_metrics_output_v1 import GetMetricsOutputV1
from .models.get_projects_output_v1 import GetProjectsOutputV1
from .models.get_request_output_v1 import GetRequestOutputV1
from .models.get_requests_output_v1 import GetRequestsOutputV1
from .models.get_sample_output_v1 import GetSampleOutputV1
from .models.get_samples_output_v1 import GetSamplesOutputV1
from .models.get_signals_output_v1 import GetSignalsOutputV1
from .models.graph_ql_input_v1 import GraphQLInputV1
from .models.graph_ql_output_v1 import GraphQLOutputV1
from .models.id_images_body import IdImagesBody
from .models.identity_mapping_list_v1 import IdentityMappingListV1
from .models.identity_mapping_v1 import IdentityMappingV1
from .models.identity_preview_list_v1 import IdentityPreviewListV1
from .models.identity_preview_v1 import IdentityPreviewV1
from .models.indexing_parameters_input_v1 import IndexingParametersInputV1
from .models.installer_output_v1 import InstallerOutputV1
from .models.interval_v1 import IntervalV1
from .models.invalid_swap_out_v1 import InvalidSwapOutV1
from .models.item_batch_output_v1 import ItemBatchOutputV1
from .models.item_dependency_output_v1 import ItemDependencyOutputV1
from .models.item_finder_configuration_v1 import ItemFinderConfigurationV1
from .models.item_finder_input_v1 import ItemFinderInputV1
from .models.item_finder_output_list_v1 import ItemFinderOutputListV1
from .models.item_finder_output_v1 import ItemFinderOutputV1
from .models.item_id_list_input_v1 import ItemIdListInputV1
from .models.item_output_v1 import ItemOutputV1
from .models.item_parameter_of_output_v1 import ItemParameterOfOutputV1
from .models.item_preview_list_v1 import ItemPreviewListV1
from .models.item_preview_v1 import ItemPreviewV1
from .models.item_preview_with_assets_v1 import ItemPreviewWithAssetsV1
from .models.item_search_preview_list_v1 import ItemSearchPreviewListV1
from .models.item_search_preview_paginated_list_v1 import ItemSearchPreviewPaginatedListV1
from .models.item_search_preview_v1 import ItemSearchPreviewV1
from .models.item_swap_result_output_v1 import ItemSwapResultOutputV1
from .models.item_update_output_v1 import ItemUpdateOutputV1
from .models.item_user_attributes_input_v1 import ItemUserAttributesInputV1
from .models.item_user_attributes_output_v1 import ItemUserAttributesOutputV1
from .models.item_with_swap_pairs_v1 import ItemWithSwapPairsV1
from .models.jira_attachment import JiraAttachment
from .models.jira_attachment_media_type import JiraAttachmentMediaType
from .models.job_accepted_output_v1 import JobAcceptedOutputV1
from .models.job_output_v1 import JobOutputV1
from .models.json_backup_output_v1 import JsonBackupOutputV1
from .models.label_category_input_v1 import LabelCategoryInputV1
from .models.label_category_output_list_v1 import LabelCategoryOutputListV1
from .models.label_category_output_v1 import LabelCategoryOutputV1
from .models.label_input_v1 import LabelInputV1
from .models.label_output_list_v1 import LabelOutputListV1
from .models.label_output_v1 import LabelOutputV1
from .models.license_importer_output_v1 import LicenseImporterOutputV1
from .models.license_status_output_v1 import LicenseStatusOutputV1
from .models.licensed_feature_status_output_v1 import LicensedFeatureStatusOutputV1
from .models.log_message import LogMessage
from .models.long_configuration_field_output_v1 import LongConfigurationFieldOutputV1
from .models.meter_datum_v1 import MeterDatumV1
from .models.migrate_editor_input_v1 import MigrateEditorInputV1
from .models.monitor_definition_output_v1 import MonitorDefinitionOutputV1
from .models.monitor_definitions_output_v1 import MonitorDefinitionsOutputV1
from .models.monitor_input_v1 import MonitorInputV1
from .models.monitor_output_v1 import MonitorOutputV1
from .models.monitor_values import MonitorValues
from .models.monitors_output_v1 import MonitorsOutputV1
from .models.notifiable_report_output_list_v1 import NotifiableReportOutputListV1
from .models.notifiable_report_output_v1 import NotifiableReportOutputV1
from .models.notification_configuration_output_v1 import NotificationConfigurationOutputV1
from .models.optional_report_input_v1 import OptionalReportInputV1
from .models.parameter_doc_output_v1 import ParameterDocOutputV1
from .models.permissions_v1 import PermissionsV1
from .models.plugin_output_list_v1 import PluginOutputListV1
from .models.plugin_output_v1 import PluginOutputV1
from .models.plugins_body import PluginsBody
from .models.pre_provision_input_v1 import PreProvisionInputV1
from .models.pre_provision_output_v1 import PreProvisionOutputV1
from .models.priority_v1 import PriorityV1
from .models.progress_information_output_v1 import ProgressInformationOutputV1
from .models.project_input_v1 import ProjectInputV1
from .models.project_output_v1 import ProjectOutputV1
from .models.property_href_output_v1 import PropertyHrefOutputV1
from .models.property_input_v1 import PropertyInputV1
from .models.property_output_v1 import PropertyOutputV1
from .models.provision_input_v1 import ProvisionInputV1
from .models.put_asset_input_v1 import PutAssetInputV1
from .models.put_scalar_input_v1 import PutScalarInputV1
from .models.put_scalars_input_v1 import PutScalarsInputV1
from .models.put_signals_input_v1 import PutSignalsInputV1
from .models.put_user_groups_input_v1 import PutUserGroupsInputV1
from .models.referenced_items_output_v1 import ReferencedItemsOutputV1
from .models.regression_output_v1 import RegressionOutputV1
from .models.remote_agent_directives_output_v1 import RemoteAgentDirectivesOutputV1
from .models.remote_agent_status_input_v1 import RemoteAgentStatusInputV1
from .models.remote_agent_status_output_v1 import RemoteAgentStatusOutputV1
from .models.report_input_item_v1 import ReportInputItemV1
from .models.report_input_v1 import ReportInputV1
from .models.report_notification_configuration_input_v1 import ReportNotificationConfigurationInputV1
from .models.report_template_input_v1 import ReportTemplateInputV1
from .models.report_template_output_v1 import ReportTemplateOutputV1
from .models.request_output_v1 import RequestOutputV1
from .models.sample_input_v1 import SampleInputV1
from .models.sample_output_v1 import SampleOutputV1
from .models.samples_input_v1 import SamplesInputV1
from .models.samples_output_v1 import SamplesOutputV1
from .models.samples_overwrite_input_v1 import SamplesOverwriteInputV1
from .models.scalar_evaluate_output_v1 import ScalarEvaluateOutputV1
from .models.scalar_input_v1 import ScalarInputV1
from .models.scalar_property_v1 import ScalarPropertyV1
from .models.scalar_value_output_v1 import ScalarValueOutputV1
from .models.scale_across_tree_output_v1 import ScaleAcrossTreeOutputV1
from .models.schedulable_admin_list_output_v1 import SchedulableAdminListOutputV1
from .models.schedulable_admin_output_v1 import SchedulableAdminOutputV1
from .models.schedulable_summary_day_output_v1 import SchedulableSummaryDayOutputV1
from .models.schedulable_summary_week_output_v1 import SchedulableSummaryWeekOutputV1
from .models.schedule_input_v1 import ScheduleInputV1
from .models.schedule_output_v1 import ScheduleOutputV1
from .models.scheduled_notebook_input_v1 import ScheduledNotebookInputV1
from .models.scheduled_notebook_list_output_v1 import ScheduledNotebookListOutputV1
from .models.scheduled_notebook_output_v1 import ScheduledNotebookOutputV1
from .models.scim_token_output_v1 import ScimTokenOutputV1
from .models.screenshot_output_v1 import ScreenshotOutputV1
from .models.secret_configuration_field_output_v1 import SecretConfigurationFieldOutputV1
from .models.see_also_doc_output_v1 import SeeAlsoDocOutputV1
from .models.send_email_attachment_v1 import SendEmailAttachmentV1
from .models.send_email_contact_v1 import SendEmailContactV1
from .models.send_email_input_v1 import SendEmailInputV1
from .models.sent_email_attachment_output_v1 import SentEmailAttachmentOutputV1
from .models.sent_email_output_v1 import SentEmailOutputV1
from .models.sent_emails_list_output_v1 import SentEmailsListOutputV1
from .models.server_build_info_output_v1 import ServerBuildInfoOutputV1
from .models.server_load_output_v1 import ServerLoadOutputV1
from .models.server_spec_output_v1 import ServerSpecOutputV1
from .models.server_status_output_v1 import ServerStatusOutputV1
from .models.signal_input_v1 import SignalInputV1
from .models.signal_output_v1 import SignalOutputV1
from .models.signal_with_id_input_v1 import SignalWithIdInputV1
from .models.status_message import StatusMessage
from .models.status_message_base import StatusMessageBase
from .models.store_secret_input_v1 import StoreSecretInputV1
from .models.string_configuration_field_output_v1 import StringConfigurationFieldOutputV1
from .models.subscription_input_v1 import SubscriptionInputV1
from .models.subscription_output_v1 import SubscriptionOutputV1
from .models.subscription_update_input_v1 import SubscriptionUpdateInputV1
from .models.support_request_input_v1 import SupportRequestInputV1
from .models.support_request_output_v1 import SupportRequestOutputV1
from .models.supported_units_output_v1 import SupportedUnitsOutputV1
from .models.swap_input_v1 import SwapInputV1
from .models.swap_option_list_v1 import SwapOptionListV1
from .models.swap_option_v1 import SwapOptionV1
from .models.swap_output_v1 import SwapOutputV1
from .models.sync_progress import SyncProgress
from .models.sync_progress_output_v1 import SyncProgressOutputV1
from .models.system_license_body import SystemLicenseBody
from .models.table_column_output_v1 import TableColumnOutputV1
from .models.table_definition_input_v1 import TableDefinitionInputV1
from .models.table_definition_output_list_v1 import TableDefinitionOutputListV1
from .models.table_definition_output_v1 import TableDefinitionOutputV1
from .models.table_definition_update_input_v1 import TableDefinitionUpdateInputV1
from .models.threshold_metric_input_v1 import ThresholdMetricInputV1
from .models.threshold_metric_output_v1 import ThresholdMetricOutputV1
from .models.threshold_output_v1 import ThresholdOutputV1
from .models.timer_datum_v1 import TimerDatumV1
from .models.tree_item_output_v1 import TreeItemOutputV1
from .models.treemap_item_output_v1 import TreemapItemOutputV1
from .models.treemap_output_v1 import TreemapOutputV1
from .models.units_of_measure_batch_input_v1 import UnitsOfMeasureBatchInputV1
from .models.units_of_measure_item_v1 import UnitsOfMeasureItemV1
from .models.units_of_measure_output_v1 import UnitsOfMeasureOutputV1
from .models.unsubscribe_output_v1 import UnsubscribeOutputV1
from .models.usage_output_list_v1 import UsageOutputListV1
from .models.usage_output_v1 import UsageOutputV1
from .models.usage_types_v1 import UsageTypesV1
from .models.user_group_input_v1 import UserGroupInputV1
from .models.user_group_output_v1 import UserGroupOutputV1
from .models.user_group_with_id_input_v1 import UserGroupWithIdInputV1
from .models.user_input_v1 import UserInputV1
from .models.user_output_list_v1 import UserOutputListV1
from .models.user_output_v1 import UserOutputV1
from .models.user_password_input_v1 import UserPasswordInputV1
from .models.validate_cron_list_input_v1 import ValidateCronListInputV1
from .models.validate_cron_list_output_v1 import ValidateCronListOutputV1
from .models.validate_cron_output_v1 import ValidateCronOutputV1
from .models.workbench_item_output_list_v1 import WorkbenchItemOutputListV1
from .models.workbench_search_result_preview_v1 import WorkbenchSearchResultPreviewV1
from .models.workbook_input_v1 import WorkbookInputV1
from .models.workbook_output_list_v1 import WorkbookOutputListV1
from .models.workbook_output_v1 import WorkbookOutputV1
from .models.worksheet_input_v1 import WorksheetInputV1
from .models.worksheet_output_list_v1 import WorksheetOutputListV1
from .models.worksheet_output_v1 import WorksheetOutputV1
from .models.workstep_input_v1 import WorkstepInputV1
from .models.workstep_output_v1 import WorkstepOutputV1

from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TreemapOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'errors': 'list[FormulaCompilerErrorOutputV1]',
        'metadata': 'dict(str, str)',
        'parent_asset': 'AssetOutputV1',
        'return_type': 'str',
        'status_message': 'str',
        'tree': 'list[TreemapItemOutputV1]',
        'upgrade_details': 'FormulaUpgradeOutputV1',
        'warning_count': 'int',
        'warning_logs': 'list[FormulaLogV1]'
    }

    attribute_map = {
        'errors': 'errors',
        'metadata': 'metadata',
        'parent_asset': 'parentAsset',
        'return_type': 'returnType',
        'status_message': 'statusMessage',
        'tree': 'tree',
        'upgrade_details': 'upgradeDetails',
        'warning_count': 'warningCount',
        'warning_logs': 'warningLogs'
    }

    def __init__(self, errors=None, metadata=None, parent_asset=None, return_type=None, status_message=None, tree=None, upgrade_details=None, warning_count=None, warning_logs=None):
        """
        TreemapOutputV1 - a model defined in Swagger
        """

        self._errors = None
        self._metadata = None
        self._parent_asset = None
        self._return_type = None
        self._status_message = None
        self._tree = None
        self._upgrade_details = None
        self._warning_count = None
        self._warning_logs = None

        if errors is not None:
          self.errors = errors
        if metadata is not None:
          self.metadata = metadata
        if parent_asset is not None:
          self.parent_asset = parent_asset
        if return_type is not None:
          self.return_type = return_type
        if status_message is not None:
          self.status_message = status_message
        if tree is not None:
          self.tree = tree
        if upgrade_details is not None:
          self.upgrade_details = upgrade_details
        if warning_count is not None:
          self.warning_count = warning_count
        if warning_logs is not None:
          self.warning_logs = warning_logs

    @property
    def errors(self):
        """
        Gets the errors of this TreemapOutputV1.
        Errors (if any) from the formula

        :return: The errors of this TreemapOutputV1.
        :rtype: list[FormulaCompilerErrorOutputV1]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this TreemapOutputV1.
        Errors (if any) from the formula

        :param errors: The errors of this TreemapOutputV1.
        :type: list[FormulaCompilerErrorOutputV1]
        """

        self._errors = errors

    @property
    def metadata(self):
        """
        Gets the metadata of this TreemapOutputV1.
        Metadata describing the compiled formula's result

        :return: The metadata of this TreemapOutputV1.
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TreemapOutputV1.
        Metadata describing the compiled formula's result

        :param metadata: The metadata of this TreemapOutputV1.
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def parent_asset(self):
        """
        Gets the parent_asset of this TreemapOutputV1.

        :return: The parent_asset of this TreemapOutputV1.
        :rtype: AssetOutputV1
        """
        return self._parent_asset

    @parent_asset.setter
    def parent_asset(self, parent_asset):
        """
        Sets the parent_asset of this TreemapOutputV1.

        :param parent_asset: The parent_asset of this TreemapOutputV1.
        :type: AssetOutputV1
        """

        self._parent_asset = parent_asset

    @property
    def return_type(self):
        """
        Gets the return_type of this TreemapOutputV1.
        The data type of the compiled formula's result

        :return: The return_type of this TreemapOutputV1.
        :rtype: str
        """
        return self._return_type

    @return_type.setter
    def return_type(self, return_type):
        """
        Sets the return_type of this TreemapOutputV1.
        The data type of the compiled formula's result

        :param return_type: The return_type of this TreemapOutputV1.
        :type: str
        """

        self._return_type = return_type

    @property
    def status_message(self):
        """
        Gets the status_message of this TreemapOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :return: The status_message of this TreemapOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this TreemapOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :param status_message: The status_message of this TreemapOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def tree(self):
        """
        Gets the tree of this TreemapOutputV1.
        The size and priority of child leaf assets or aggregations of child asset trees.

        :return: The tree of this TreemapOutputV1.
        :rtype: list[TreemapItemOutputV1]
        """
        return self._tree

    @tree.setter
    def tree(self, tree):
        """
        Sets the tree of this TreemapOutputV1.
        The size and priority of child leaf assets or aggregations of child asset trees.

        :param tree: The tree of this TreemapOutputV1.
        :type: list[TreemapItemOutputV1]
        """

        self._tree = tree

    @property
    def upgrade_details(self):
        """
        Gets the upgrade_details of this TreemapOutputV1.

        :return: The upgrade_details of this TreemapOutputV1.
        :rtype: FormulaUpgradeOutputV1
        """
        return self._upgrade_details

    @upgrade_details.setter
    def upgrade_details(self, upgrade_details):
        """
        Sets the upgrade_details of this TreemapOutputV1.

        :param upgrade_details: The upgrade_details of this TreemapOutputV1.
        :type: FormulaUpgradeOutputV1
        """

        self._upgrade_details = upgrade_details

    @property
    def warning_count(self):
        """
        Gets the warning_count of this TreemapOutputV1.
        The total number of warnings that have occurred

        :return: The warning_count of this TreemapOutputV1.
        :rtype: int
        """
        return self._warning_count

    @warning_count.setter
    def warning_count(self, warning_count):
        """
        Sets the warning_count of this TreemapOutputV1.
        The total number of warnings that have occurred

        :param warning_count: The warning_count of this TreemapOutputV1.
        :type: int
        """

        self._warning_count = warning_count

    @property
    def warning_logs(self):
        """
        Gets the warning_logs of this TreemapOutputV1.
        The Formula warning logs, which includes the text, line number, and column number where the warning occurred in addition to the warning details

        :return: The warning_logs of this TreemapOutputV1.
        :rtype: list[FormulaLogV1]
        """
        return self._warning_logs

    @warning_logs.setter
    def warning_logs(self, warning_logs):
        """
        Sets the warning_logs of this TreemapOutputV1.
        The Formula warning logs, which includes the text, line number, and column number where the warning occurred in addition to the warning details

        :param warning_logs: The warning_logs of this TreemapOutputV1.
        :type: list[FormulaLogV1]
        """

        self._warning_logs = warning_logs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TreemapOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConfigurationOptionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'advanced': 'bool',
        'allowed_values': 'str',
        'default_dependencies': 'list[str]',
        'default_description': 'str',
        'default_value': 'object',
        'description': 'str',
        'modifiable': 'bool',
        'note': 'str',
        'path': 'str',
        'registration': 'str',
        'registration_description': 'str',
        'units': 'str',
        'value': 'object'
    }

    attribute_map = {
        'advanced': 'advanced',
        'allowed_values': 'allowedValues',
        'default_dependencies': 'defaultDependencies',
        'default_description': 'defaultDescription',
        'default_value': 'defaultValue',
        'description': 'description',
        'modifiable': 'modifiable',
        'note': 'note',
        'path': 'path',
        'registration': 'registration',
        'registration_description': 'registrationDescription',
        'units': 'units',
        'value': 'value'
    }

    def __init__(self, advanced=None, allowed_values=None, default_dependencies=None, default_description=None, default_value=None, description=None, modifiable=None, note=None, path=None, registration=None, registration_description=None, units=None, value=None):
        """
        ConfigurationOptionOutputV1 - a model defined in Swagger
        """

        self._advanced = None
        self._allowed_values = None
        self._default_dependencies = None
        self._default_description = None
        self._default_value = None
        self._description = None
        self._modifiable = None
        self._note = None
        self._path = None
        self._registration = None
        self._registration_description = None
        self._units = None
        self._value = None

        if advanced is not None:
          self.advanced = advanced
        if allowed_values is not None:
          self.allowed_values = allowed_values
        if default_dependencies is not None:
          self.default_dependencies = default_dependencies
        if default_description is not None:
          self.default_description = default_description
        if default_value is not None:
          self.default_value = default_value
        if description is not None:
          self.description = description
        if modifiable is not None:
          self.modifiable = modifiable
        if note is not None:
          self.note = note
        if path is not None:
          self.path = path
        if registration is not None:
          self.registration = registration
        if registration_description is not None:
          self.registration_description = registration_description
        if units is not None:
          self.units = units
        if value is not None:
          self.value = value

    @property
    def advanced(self):
        """
        Gets the advanced of this ConfigurationOptionOutputV1.

        :return: The advanced of this ConfigurationOptionOutputV1.
        :rtype: bool
        """
        return self._advanced

    @advanced.setter
    def advanced(self, advanced):
        """
        Sets the advanced of this ConfigurationOptionOutputV1.

        :param advanced: The advanced of this ConfigurationOptionOutputV1.
        :type: bool
        """

        self._advanced = advanced

    @property
    def allowed_values(self):
        """
        Gets the allowed_values of this ConfigurationOptionOutputV1.

        :return: The allowed_values of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._allowed_values

    @allowed_values.setter
    def allowed_values(self, allowed_values):
        """
        Sets the allowed_values of this ConfigurationOptionOutputV1.

        :param allowed_values: The allowed_values of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._allowed_values = allowed_values

    @property
    def default_dependencies(self):
        """
        Gets the default_dependencies of this ConfigurationOptionOutputV1.

        :return: The default_dependencies of this ConfigurationOptionOutputV1.
        :rtype: list[str]
        """
        return self._default_dependencies

    @default_dependencies.setter
    def default_dependencies(self, default_dependencies):
        """
        Sets the default_dependencies of this ConfigurationOptionOutputV1.

        :param default_dependencies: The default_dependencies of this ConfigurationOptionOutputV1.
        :type: list[str]
        """

        self._default_dependencies = default_dependencies

    @property
    def default_description(self):
        """
        Gets the default_description of this ConfigurationOptionOutputV1.

        :return: The default_description of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._default_description

    @default_description.setter
    def default_description(self, default_description):
        """
        Sets the default_description of this ConfigurationOptionOutputV1.

        :param default_description: The default_description of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._default_description = default_description

    @property
    def default_value(self):
        """
        Gets the default_value of this ConfigurationOptionOutputV1.

        :return: The default_value of this ConfigurationOptionOutputV1.
        :rtype: object
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this ConfigurationOptionOutputV1.

        :param default_value: The default_value of this ConfigurationOptionOutputV1.
        :type: object
        """

        self._default_value = default_value

    @property
    def description(self):
        """
        Gets the description of this ConfigurationOptionOutputV1.

        :return: The description of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConfigurationOptionOutputV1.

        :param description: The description of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._description = description

    @property
    def modifiable(self):
        """
        Gets the modifiable of this ConfigurationOptionOutputV1.

        :return: The modifiable of this ConfigurationOptionOutputV1.
        :rtype: bool
        """
        return self._modifiable

    @modifiable.setter
    def modifiable(self, modifiable):
        """
        Sets the modifiable of this ConfigurationOptionOutputV1.

        :param modifiable: The modifiable of this ConfigurationOptionOutputV1.
        :type: bool
        """

        self._modifiable = modifiable

    @property
    def note(self):
        """
        Gets the note of this ConfigurationOptionOutputV1.

        :return: The note of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """
        Sets the note of this ConfigurationOptionOutputV1.

        :param note: The note of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._note = note

    @property
    def path(self):
        """
        Gets the path of this ConfigurationOptionOutputV1.

        :return: The path of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ConfigurationOptionOutputV1.

        :param path: The path of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._path = path

    @property
    def registration(self):
        """
        Gets the registration of this ConfigurationOptionOutputV1.

        :return: The registration of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._registration

    @registration.setter
    def registration(self, registration):
        """
        Sets the registration of this ConfigurationOptionOutputV1.

        :param registration: The registration of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._registration = registration

    @property
    def registration_description(self):
        """
        Gets the registration_description of this ConfigurationOptionOutputV1.

        :return: The registration_description of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._registration_description

    @registration_description.setter
    def registration_description(self, registration_description):
        """
        Sets the registration_description of this ConfigurationOptionOutputV1.

        :param registration_description: The registration_description of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._registration_description = registration_description

    @property
    def units(self):
        """
        Gets the units of this ConfigurationOptionOutputV1.

        :return: The units of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """
        Sets the units of this ConfigurationOptionOutputV1.

        :param units: The units of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._units = units

    @property
    def value(self):
        """
        Gets the value of this ConfigurationOptionOutputV1.

        :return: The value of this ConfigurationOptionOutputV1.
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ConfigurationOptionOutputV1.

        :param value: The value of this ConfigurationOptionOutputV1.
        :type: object
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConfigurationOptionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'arguments': 'dict(str, str)',
        'input_column1': 'str',
        'input_column2': 'str',
        'rule': 'str'
    }

    attribute_map = {
        'arguments': 'arguments',
        'input_column1': 'inputColumn1',
        'input_column2': 'inputColumn2',
        'rule': 'rule'
    }

    def __init__(self, arguments=None, input_column1=None, input_column2=None, rule=None):
        """
        ColumnRuleOutputV1 - a model defined in Swagger
        """

        self._arguments = None
        self._input_column1 = None
        self._input_column2 = None
        self._rule = None

        if arguments is not None:
          self.arguments = arguments
        if input_column1 is not None:
          self.input_column1 = input_column1
        if input_column2 is not None:
          self.input_column2 = input_column2
        if rule is not None:
          self.rule = rule

    @property
    def arguments(self):
        """
        Gets the arguments of this ColumnRuleOutputV1.
        The column rule arguments

        :return: The arguments of this ColumnRuleOutputV1.
        :rtype: dict(str, str)
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """
        Sets the arguments of this ColumnRuleOutputV1.
        The column rule arguments

        :param arguments: The arguments of this ColumnRuleOutputV1.
        :type: dict(str, str)
        """

        self._arguments = arguments

    @property
    def input_column1(self):
        """
        Gets the input_column1 of this ColumnRuleOutputV1.
        The column rule input column 1 ID

        :return: The input_column1 of this ColumnRuleOutputV1.
        :rtype: str
        """
        return self._input_column1

    @input_column1.setter
    def input_column1(self, input_column1):
        """
        Sets the input_column1 of this ColumnRuleOutputV1.
        The column rule input column 1 ID

        :param input_column1: The input_column1 of this ColumnRuleOutputV1.
        :type: str
        """

        self._input_column1 = input_column1

    @property
    def input_column2(self):
        """
        Gets the input_column2 of this ColumnRuleOutputV1.
        The column rule input column 2 ID

        :return: The input_column2 of this ColumnRuleOutputV1.
        :rtype: str
        """
        return self._input_column2

    @input_column2.setter
    def input_column2(self, input_column2):
        """
        Sets the input_column2 of this ColumnRuleOutputV1.
        The column rule input column 2 ID

        :param input_column2: The input_column2 of this ColumnRuleOutputV1.
        :type: str
        """

        self._input_column2 = input_column2

    @property
    def rule(self):
        """
        Gets the rule of this ColumnRuleOutputV1.
        The column rule name

        :return: The rule of this ColumnRuleOutputV1.
        :rtype: str
        """
        return self._rule

    @rule.setter
    def rule(self, rule):
        """
        Sets the rule of this ColumnRuleOutputV1.
        The column rule name

        :param rule: The rule of this ColumnRuleOutputV1.
        :type: str
        """

        self._rule = rule

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SendEmailInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'to_emails': 'list[SendEmailContactV1]',
        'cc_emails': 'list[SendEmailContactV1]',
        'bcc_emails': 'list[SendEmailContactV1]',
        'subject': 'str',
        'content': 'str',
        'attachments': 'list[SendEmailAttachmentV1]'
    }

    attribute_map = {
        'to_emails': 'toEmails',
        'cc_emails': 'ccEmails',
        'bcc_emails': 'bccEmails',
        'subject': 'subject',
        'content': 'content',
        'attachments': 'attachments'
    }

    def __init__(self, to_emails=None, cc_emails=None, bcc_emails=None, subject=None, content=None, attachments=None):
        """
        SendEmailInputV1 - a model defined in Swagger
        """

        self._to_emails = None
        self._cc_emails = None
        self._bcc_emails = None
        self._subject = None
        self._content = None
        self._attachments = None

        if to_emails is not None:
          self.to_emails = to_emails
        if cc_emails is not None:
          self.cc_emails = cc_emails
        if bcc_emails is not None:
          self.bcc_emails = bcc_emails
        if subject is not None:
          self.subject = subject
        if content is not None:
          self.content = content
        if attachments is not None:
          self.attachments = attachments

    @property
    def to_emails(self):
        """
        Gets the to_emails of this SendEmailInputV1.
        List of email recipients to use in the TO attribute of the email.

        :return: The to_emails of this SendEmailInputV1.
        :rtype: list[SendEmailContactV1]
        """
        return self._to_emails

    @to_emails.setter
    def to_emails(self, to_emails):
        """
        Sets the to_emails of this SendEmailInputV1.
        List of email recipients to use in the TO attribute of the email.

        :param to_emails: The to_emails of this SendEmailInputV1.
        :type: list[SendEmailContactV1]
        """
        if to_emails is None:
            raise ValueError("Invalid value for `to_emails`, must not be `None`")

        self._to_emails = to_emails

    @property
    def cc_emails(self):
        """
        Gets the cc_emails of this SendEmailInputV1.
        List of email recipients to use in the CC attribute of the email.

        :return: The cc_emails of this SendEmailInputV1.
        :rtype: list[SendEmailContactV1]
        """
        return self._cc_emails

    @cc_emails.setter
    def cc_emails(self, cc_emails):
        """
        Sets the cc_emails of this SendEmailInputV1.
        List of email recipients to use in the CC attribute of the email.

        :param cc_emails: The cc_emails of this SendEmailInputV1.
        :type: list[SendEmailContactV1]
        """
        if cc_emails is None:
            raise ValueError("Invalid value for `cc_emails`, must not be `None`")

        self._cc_emails = cc_emails

    @property
    def bcc_emails(self):
        """
        Gets the bcc_emails of this SendEmailInputV1.
        List of email recipients to use in the BCC attribute of the email.

        :return: The bcc_emails of this SendEmailInputV1.
        :rtype: list[SendEmailContactV1]
        """
        return self._bcc_emails

    @bcc_emails.setter
    def bcc_emails(self, bcc_emails):
        """
        Sets the bcc_emails of this SendEmailInputV1.
        List of email recipients to use in the BCC attribute of the email.

        :param bcc_emails: The bcc_emails of this SendEmailInputV1.
        :type: list[SendEmailContactV1]
        """
        if bcc_emails is None:
            raise ValueError("Invalid value for `bcc_emails`, must not be `None`")

        self._bcc_emails = bcc_emails

    @property
    def subject(self):
        """
        Gets the subject of this SendEmailInputV1.
        Subject of the email.

        :return: The subject of this SendEmailInputV1.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this SendEmailInputV1.
        Subject of the email.

        :param subject: The subject of this SendEmailInputV1.
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")

        self._subject = subject

    @property
    def content(self):
        """
        Gets the content of this SendEmailInputV1.
        HTML body of the email.

        :return: The content of this SendEmailInputV1.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this SendEmailInputV1.
        HTML body of the email.

        :param content: The content of this SendEmailInputV1.
        :type: str
        """
        if content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")

        self._content = content

    @property
    def attachments(self):
        """
        Gets the attachments of this SendEmailInputV1.
        List of attachments for the email.

        :return: The attachments of this SendEmailInputV1.
        :rtype: list[SendEmailAttachmentV1]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """
        Sets the attachments of this SendEmailInputV1.
        List of attachments for the email.

        :param attachments: The attachments of this SendEmailInputV1.
        :type: list[SendEmailAttachmentV1]
        """
        if attachments is None:
            raise ValueError("Invalid value for `attachments`, must not be `None`")

        self._attachments = attachments

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SendEmailInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 64.1.2-v202403201906
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConfiguredDirectivesOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'installers': 'list[InstallerOutputV1]',
        'run_version': 'str',
        'stage_installer': 'str'
    }

    attribute_map = {
        'installers': 'installers',
        'run_version': 'runVersion',
        'stage_installer': 'stageInstaller'
    }

    def __init__(self, installers=None, run_version=None, stage_installer=None):
        """
        ConfiguredDirectivesOutputV1 - a model defined in Swagger
        """

        self._installers = None
        self._run_version = None
        self._stage_installer = None

        if installers is not None:
          self.installers = installers
        if run_version is not None:
          self.run_version = run_version
        if stage_installer is not None:
          self.stage_installer = stage_installer

    @property
    def installers(self):
        """
        Gets the installers of this ConfiguredDirectivesOutputV1.
        List of installers

        :return: The installers of this ConfiguredDirectivesOutputV1.
        :rtype: list[InstallerOutputV1]
        """
        return self._installers

    @installers.setter
    def installers(self, installers):
        """
        Sets the installers of this ConfiguredDirectivesOutputV1.
        List of installers

        :param installers: The installers of this ConfiguredDirectivesOutputV1.
        :type: list[InstallerOutputV1]
        """

        self._installers = installers

    @property
    def run_version(self):
        """
        Gets the run_version of this ConfiguredDirectivesOutputV1.
        Run Version

        :return: The run_version of this ConfiguredDirectivesOutputV1.
        :rtype: str
        """
        return self._run_version

    @run_version.setter
    def run_version(self, run_version):
        """
        Sets the run_version of this ConfiguredDirectivesOutputV1.
        Run Version

        :param run_version: The run_version of this ConfiguredDirectivesOutputV1.
        :type: str
        """

        self._run_version = run_version

    @property
    def stage_installer(self):
        """
        Gets the stage_installer of this ConfiguredDirectivesOutputV1.
        Staged Installer

        :return: The stage_installer of this ConfiguredDirectivesOutputV1.
        :rtype: str
        """
        return self._stage_installer

    @stage_installer.setter
    def stage_installer(self, stage_installer):
        """
        Sets the stage_installer of this ConfiguredDirectivesOutputV1.
        Staged Installer

        :param stage_installer: The stage_installer of this ConfiguredDirectivesOutputV1.
        :type: str
        """

        self._stage_installer = stage_installer

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConfiguredDirectivesOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
